pub fn classify(id: ResourceId) -> Option<CiPlusResource>Expand description
Map a ResourceId to the CI Plus resource it denotes, or None for any
resource not dispatched by CiPlusApdu.
pub fn classify(id: ResourceId) -> Option<CiPlusResource>Map a ResourceId to the CI Plus resource it denotes, or None for any
resource not dispatched by CiPlusApdu.