StreamInput objects — ETSI TS 101 699 V1.1.1 6.1.2, Tables 12-20
(PDF pp. 25-28). See docs/ci_plus/input-modules.md.
Resource ID 0x00801ii1 (ii = Module ID), single session. A Type ‘A’ input
module presents StreamInput: it delivers broadcast services at the TS
level; the host scans for, and tunes to, transport streams.
DeliverySystemInfoReq(9F 80 00, Table 13) — host → module: header-only.DeliverySystemInfoAck(9F 80 01, Table 14) — module → host: a list ofSystemIdentifiers (Table 15: 0=Abstract, 1=DVB-C, 2=DVB-S, 3=DVB-T).ScanStartReq(9F 80 02, Table 16) — host → module: header-only.ScanNextReq(9F 80 03, Table 17) — host → module: header-only.ScanAck(9F 80 04, Table 18) — module → host:TSState+ 11-byteTuningInformationMessage+ScanProgress.TuneTSReq(9F 80 05, Table 19) — host → module: an (optional) 11-byteTuningInformationMessage(absent = disconnect from network).TuneTSAck(9F 80 06, Table 20) — module → host:TSState.
Modules
- tag
- Resource-scoped
apdu_tags for StreamInput (Tables 13-20).
Structs
- Delivery
System Info Ack DeliverySystemInfoAck()(Table 14) — module → host: the delivery systems the module is connected to (oneSystemIdentifierper byte).- Delivery
System Info Req DeliverySystemInfoReq()(Table 13) — host → module: header-only.- ScanAck
ScanAck()(Table 18) — module → host: a TS found during a scan.- Scan
Next Req ScanNextReq()(Table 17) — host → module: header-only.- Scan
Start Req ScanStartReq()(Table 16) — host → module: header-only.- TuneTS
Ack TuneTSAck()(Table 20) — module → host: tune result.- TuneTS
Req TuneTSReq()(Table 19) — host → module: tune to a TS. An absentTuningInformationMessage(zero following bytes) requests a network disconnect.
Enums
- Stream
Input Apdu - Resource-scoped dispatch over the StreamInput objects (Tables 13-20).
- System
Identifier SystemIdentifier— the delivery system a module connects to (Table 15).
Constants
- TUNING_
INFO_ MESSAGE_ LEN - Length of a
TuningInformationMessage— always 11 bytes (11 x 8, 6.1.1).